# Модули Ansible для управления облачными ресурсами в платформе DECORT
## Введение

Настоящая документация содержит руководство пользователя по библиотеке модулей decort для Ansible. С помощью этих модулей Вы сможете управлять созданием и конфигурированием облачных ресурсов в платформе DECORT (Digital Energy Cloud Orchestration Technology).

У каждого модуля есть свой раздел, в котором Вы можете найти подробную информацию о параметрах, которые использует и возращает данный модуль, а также примеры использования данного модуля.

В состав библиотеки модулей DECORT для Ansible на текущий момент входят:

- decort_kvmvm - модуль для управления жизненным циклом виртуальных серверов (экземпляров compute). Платформа DECORT поддерживает виртуальные серверы на базе технологии KVM и аппаратных архитектур Intel x86 и IBM PowerPC.
Позволяет:
  1. Создавать новые виртуальные сервера указанной аппаратной архитектуры. Платформа поддерживает виртуальные сервера архитектуры Intel x86 и IBM PowerPC.
  2. Изменять конфигурацию существующего виртуального сервера:
    - Изменять количества выделенных CPU и виртуальной ОЗУ. Следует иметь ввиду, что изменение этих параметров в меньшую сторону может потребовать перезагрузки гостевой ОС.
    - Увеличивать размера загрузочного диска
    - Подключать / отключать дополнительные дисковые ресурсы.
    - Создавать / удалять сетевые подключения.
  3. Изменять состояние существующего виртуального сервера:
    - Выключать / включать.
    - Перезагружать, приостанаваливать / возобновлять работу гостевой ОС.
  4. Удалять существующий виртуальный сервер.
  5. Получать информацию о существующем виртуальном сервере без изменения его конфигурации.
- decort_disk - модуль для управления жизненным циклом дисковых ресурсов, которые можно подключать к экземплярам compute.
Позволяет:
  1) создавать / удалять диск;
  2) изменять размер диска.
- decort_rg - модуль для управления жизненным циклом ресурсных групп (Resource Groups, RG).
Позволяет:
  1) Создавать\удалять ресурсные группы.
  2) Запрашивать информацию об уже существующих ресурсных группах.
  3) Редактировать ресурсные группы.
  4) Настраивать квоты в ресурсных группах.
  5) Восстанавливать ресурсные группы.
- decort_vins - модуль для управления жизненным циклом виртуальных сетевых сегментов (Virtual Network Segment, ViNS). Экземпляры compute (напр., виртуальные серверы) могут быть подключены к нескольким виртуальным сетевым сегментам.
Позволяет:
  1) Создавать, удалять виртуальные сетевые сегменты.
  2) Изменять виртуальные сетевые сегменты.
  3) Запрашивать информацию о виртуальных сетевых сегментах.
  4) Восстанавливать удалённые виртуальные сетевые сегменты.

- decort_pfw - модуль для настройки правил трансляции сетевых портов виртуальных серверов.
- decort_osimage - модуль для взаимодействия с образами.
Позволяет:
  1) Создавать новый образ операционной системы для виртуальных машин.
  2) Создавать виртуальный образ для образа операционной системы.
  3) Изменять имя образа (в случае изменения имени виртуального образа, имя и id виртуального образа указываются как image_name и image_id).
  4) Привязывать другой образ операционной системы к виртуальному образу.
  5) Удалять существующий образ, привязанный к аккаунту.
  6) Получать информацию об образе.
- decort_jwt - модуль для получения авторизационного токена (JWT - JSON Web Token), который можно использовать при массовом создании экземпляров compute для ускорения работы playbook-а. Подробности см. в соответствующем разделе.
- decort_bservice - модуль для взаимодействия с Basic сервисами (Basic service).
Позволяет:
  1) Создавать Basic Service.
  2) Удалять Basic Service.
  3) Включать/выключать Basic Service.
  4) Запрашивать информацию о Basic Service.
- decort_group - модуль для взаимодействия с группами виртуальных серверов(compute).
Позволяет:
  1) Получить информацию о группе виртуальных серверов.
  2) Запустить/остановить группу виртуальных серверов.
  3) Изменить параметры группы виртуальных серверов (cpu, ram, disk, и т.д).
  4) Изменить количество виртуальных серверов в группе.
  5) Изменить параметры сети (ext_net, VINS).
  6) Создать группу виртуальных серверов и подключить её к Basic сервису.
  7) Удалить группу виртуальных серверов.
- decort_k8s - модуль для взаимодействия с кластерами Kubernetes.
Позволяет:
  1) Создавать/удалять кластера Kubernetes.
  2) Enable/Disable кластера Kubernetes.
  3) Запускать/Останавливать кластера Kubernetes
  4) Модифицировать кластера Kubernetes
  5) Получать информацию об уже существующем кластере Kubernetes.

## Системные требования
Убедитесь, что Ваша система соответствует требованиям для работы модуля DECORT.
Системные требования для работы модуля:
- Ansible 2.7 or higher
- Python 3.7 or higher
- PyJWT 2.0.0 Python module or higher
- requests Python module
- netaddr Python module
- DECORT cloud platform version 3.5.0 or higher

## Подготовка к работе

Для начала работы необходимо разместить директории library и module_utils в Вашей рабочей директории, откуда будут запускаться плейбуки, либо указать в ansible.cfg путь до них.




